<?php

/** mlbl_chefs_d_etat */

declare(strict_types=1);

use Fisharebest\Localization\Translation;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Module\AbstractModule;
use Fisharebest\Webtrees\Module\ModuleCustomInterface;
use Fisharebest\Webtrees\Module\ModuleCustomTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsInterface;
use Illuminate\Support\Collection;

/** Class mlbl_chefs_d_etat */
return new class extends AbstractModule implements ModuleCustomInterface, ModuleHistoricEventsInterface
{
	use ModuleCustomTrait;
	use ModuleHistoricEventsTrait;

	public function title(): string
	{return 'MaLiBeLe Les chefs d\'état français';}

	public function description(): string
	{return "Tous les chefs d'état de la France : rois, empereurs, président de la République....";}

	public function customModuleAuthorName(): string 
	{return 'Roland Bouat';}

	/** Date = version au format AAAA-MM-JJ de préférence */
	public function customModuleVersion(): string 
	{return '2023-09-08';} 

	/** URL du fichier texte contenant la référence de la dernière version */
	public function customModuleLatestVersionUrl(): string
	{return 'https://dekri.net/webtrees_histoire-derniere_version.txt';} 

	/** URL de l'éventuelle page d'aide et/ou de présentation */
	public function customModuleSupportUrl(): string 
	{return 'https://dekri.net/spip.php?article61';}


	/**
	 * Ce module doit-il être activé lors de sa première installation ?
	 * @return bool => false (conseillé) ou true
	 */
	public function isEnabledByDefault(): bool
	{return false;}

	/**
	 * Tous les événements fournis par ce module.
	 * @return Collection<int,string>
	 */
	public function historicEventsAll(): Collection
	{
	switch (I18N::languageTag()) {
		/** Langues utilisées */
		case 'fr':
        case 'fr-CA':
		return new Collection([
		/*# France : tous les chefs d'état */
"1 EVEN Sacre de l’Empereur Charlemagne\n2 TYPE Chef d’état\n2 DATE 800\n2 NOTE voir [Charlemagne](https://fr.wikipedia.org/wiki/Charlemagne)",
"1 EVEN Sacre sans doute à Noyon du roi Hugues Capet\n2 TYPE Chef d’état\n2 DATE 3 JUL 987\n2 NOTE voir [Hugues_Capet](https://fr.wikipedia.org/wiki/Hugues_Capet)",
"1 EVEN Sacre à Orléans de Robert II « le Pieux »\n2 TYPE Chef d’état\n2 DATE 24 OCT 996\n2 NOTE Roi associé, il règnera avec son fils Hugues qui meurt en 1025\n3 CONT voir [Robert_II_le_Pieux](https://fr.wikipedia.org/wiki/Robert_II_le_Pieux)",
"1 EVEN Sacre à Reims comme roi associé le 14 mai 1027, Henri 1er devient seul roi de France\n2 TYPE Chef d’état\n2 DATE 20 JUL 1031\n2 NOTE De nouveau roi associé le 23 mai 1059 avec Philippe 1er\n3 CONT voir [Henri_Ier_(roi_des_Francs)](https://fr.wikipedia.org/wiki/Henri_Ier_(roi_des_Francs))",
"1 EVEN Sacre à Reims le 23 mai 1759 du roi Philippe 1er\n2 TYPE Chef d’état\n2 DATE 4 AUG 1060\n2 NOTE il règnera sous la régence de Baudoin V de Flandre jusqu’en 1066.\n3 CONT voir [Philippe_Ier_(roi_des_Francs)](https://fr.wikipedia.org/wiki/Philippe_Ier_(roi_des_Francs))",
"1 EVEN Sacre à Orléans le 3 août 1108 du roi Louis VI\n2 TYPE Chef d’état\n2 DATE 29 JUL 1108\n2 NOTE De 1129 à 1131 il règnera comme roi associé avec son fils Philippe\n3 CONT voir [Louis_VI_le_Gros](https://fr.wikipedia.org/wiki/Louis_VI_le_Gros)",
"1 EVEN Sacre comme roi associé à Reims du roi Louis VII\n2 TYPE Chef d’état\n2 DATE 1 AUG 1137\n2 NOTE voir [Louis_VII_le_Jeune](https://fr.wikipedia.org/wiki/Louis_VII_le_Jeune)",
"1 EVEN Sacre à Reims le 1er novembre 1179 du roi associé Philippe II « Auguste »\n2 TYPE Chef d’état\n2 DATE 18 SEP 1180\n2 NOTE Il sera le premier roi à utiliser le titre de « Roi de France »\n3 CONT voir [Philippe_II_Auguste](https://fr.wikipedia.org/wiki/Philippe_II_Auguste)",
"1 EVEN Sacre à Reims du roi Louis VIII « le Lion »\n2 TYPE Chef d’état\n2 DATE 14 JUL 1223\n2 NOTE voir [Louis_VIII_le_Lion](https://fr.wikipedia.org/wiki/Louis_VIII_le_Lion)",
"1 EVEN Sacre à Reims le 29 novembre 1226 du roi Louis IX « le Prudhomme » ou « Saint-Louis »\n2 TYPE Chef d’état\n2 DATE 8 NOV 1226\n2 NOTE Jusqu’en 1235, il règnera sous la régence de sa mère, Blanche de Castille\n3 CONT voir [Louis_IX](https://fr.wikipedia.org/wiki/Louis_IX)",
"1 EVEN Sacre à Reims le 30 août 1271 du roi Philippe III « le Hardi »\n2 TYPE Chef d’état\n2 DATE 25 AUG 1270\n2 NOTE voir [Philippe_III_le_Hardi](https://fr.wikipedia.org/wiki/Philippe_III_le_Hardi)",
"1 EVEN Sacre à Reims le 30 aout 1271 du roi Philippe IV « le Bel »\n2 TYPE Chef d’état\n2 DATE 5 OCT 1285\n2 NOTE voir [Philippe_IV_le_Bel](https://fr.wikipedia.org/wiki/Philippe_IV_le_Bel)",
"1 EVEN Sacre à Reims le 24 août 1315 du roi Louis X « le Hutin ».\n2 TYPE Chef d’état\n2 DATE 29 NOV 1314\n2 NOTE Mort avant la naissance de son fils\n3 CONT voir [Louis_X](https://fr.wikipedia.org/wiki/Louis_X)",
"1 EVEN Naissance de Jean 1er, aussitôt roi de France, son père étant mort.\n2 TYPE Chef d’état\n2 DATE 14 NOV 1316\n2 NOTE A vécu et n’a donc régné que 5 jours sous la régence de Philippe, frère de son père. Anecdote : c’est le seul roi de France à avoir régné (5 jours !) de sa naissance à sa mort.\n3 CONT voir [Jean_Ier_le_Posthume](https://fr.wikipedia.org/wiki/Jean_Ier_le_Posthume)",
"1 EVEN Sacre à Reims le 9 janvier 1317 du roi Philippe V « le Long »\n2 TYPE Chef d’état\n2 DATE 19 NOV 1316\n2 NOTE Sa nièce Jeanne, fille de Louis X, est évincée par les états généraux de 1317.\n3 CONT voir [Philippe_V_le_Long](https://fr.wikipedia.org/wiki/Philippe_V_le_Long)",
"1 EVEN Sacre à Reims le 21 février 1322 du roi Charles IV « le Bel »\n2 TYPE Chef d’état\n2 DATE 3 JAN 1322\n2 NOTE Dernier roi capétien\n3 CONT voir [Charles_IV_le_Bel](https://fr.wikipedia.org/wiki/Charles_IV_le_Bel)",
"1 EVEN Sacre à Reims le 29 mai 1328 du roi Philippe VI de Valois « le Fortuné » ou « le catholique »\n2 TYPE Chef d’état\n2 DATE 1 FEB 1328\n2 NOTE Premier roi de France de la Maison de Valois\n3 CONT voir [Philippe_VI_de_Valois](https://fr.wikipedia.org/wiki/Philippe_VI_de_Valois)",
"1 EVEN Sacre à Reims le 26 septembre 1350 du roi de France Jean II « le Bon » \n2 TYPE Chef d’état\n2 DATE 22 AUG 1350\n2 NOTE Mort en captivité à Londres\n3 CONT voir [Jean_II_le_Bon](https://fr.wikipedia.org/wiki/Jean_II_le_Bon)",
"1 EVEN Sacre à Reims le 19 mai 1364 du roi de France Charles V « le Sage » \n2 TYPE Chef d’état\n2 DATE 8 APR 1364\n2 NOTE voir [Charles_V_le_Sage](https://fr.wikipedia.org/wiki/Charles_V_le_Sage)",
"1 EVEN Sacre à Reims le 4 novembre 1380 du roi de France Charles VI « le Bien-Aimé » ou « le Fol » \n2 TYPE Chef d’état\n2 DATE 16 SEP 1380\n2 NOTE  Atteint de folie à partir de 1392\n3 CONT voir [Charles_VI_(roi_de_France)](https://fr.wikipedia.org/wiki/Charles_VI_(roi_de_France))",
"1 EVEN Sacre à Reims le 17 juillet 1429 du roi de France Charles VII « le Victorieux »\n2 TYPE Chef d’état\n2 DATE 22 OCT 1422\n2 NOTE  C’est  Jeanne d'Arc, qui après avoir levé le siège d'Orléans le conduisit se faire sacrer.\n3 CONT voir [Charles_VII_(roi_de_France)](https://fr.wikipedia.org/wiki/Charles_VII_(roi_de_France))",
"1 EVEN Sacre à Reims le 15 août 1461 du roi de France Louis XI « le Prudent » ou « Universelle Aragne »\n2 TYPE Chef d’état\n2 DATE 22 JUL 1461\n2 NOTE voir [Louis_XI](https://fr.wikipedia.org/wiki/Louis_XI)",
"1 EVEN Sacre à Reims le 30 mai 1484 du roi de France Charles VIII « l’Affable »\n2 TYPE Chef d’état\n2 DATE 30 AUG 1483\n2 NOTE  Règne d’abord sous la régence de sa sœur Anne de France jusqu’en 1491.\n3 CONT voir [Charles_VIII_(roi_de_France)](https://fr.wikipedia.org/wiki/Charles_VIII_(roi_de_France))",
"1 EVEN Sacre à Reims le 27 mai 1498 du roi de France Louis XII « le Père du Peuple »\n2 TYPE Chef d’état\n2 DATE 7 APR 1498\n2 NOTE voir [Louis_XII](https://fr.wikipedia.org/wiki/Louis_XII)",
"1 EVEN Sacre à Reims le 25 janvier 1515 du roi de France François Ier « le Père et Restaurateur des Lettres »\n2 TYPE Chef d’état\n2 DATE 1 JAN 1515\n2 NOTE voir [François_Ier_(roi_de_France)](https://fr.wikipedia.org/wiki/François_Ier_(roi_de_France))",
"1 EVEN Sacre à Reims le 26 juillet 1547 du roi de France Henri II\n2 TYPE Chef d’état\n2 DATE 31 MAR 1547\n2 NOTE voir [Henri_II_(roi_de_France)](https://fr.wikipedia.org/wiki/Henri_II_(roi_de_France))",
"1 EVEN Sacre à Reims le 18 septembre 1559 du roi de France François II\n2 TYPE Chef d’état\n2 DATE 10 JUL 1559\n2 NOTE voir [François_II_(roi_de_France)](https://fr.wikipedia.org/wiki/François_II_(roi_de_France))",
"1 EVEN Sacre à Reims le 15 mai 1561 du roi de France Charles IX\n2 TYPE Chef d’état\n2 DATE 5 DEC 1560\n2 NOTE voir [Charles_IX_(roi_de_France)](https://fr.wikipedia.org/wiki/Charles_IX_(roi_de_France))",
"1 EVEN Sacre le 13 février 1575 à Reims du roi de France Henri III\n2 TYPE Chef d’état\n2 DATE 30 MAY 1574\n2 NOTE voir [Henri_III_(roi_de_France)](https://fr.wikipedia.org/wiki/Henri_III_(roi_de_France))",
"1 EVEN Sacre à Chartres le 27 février 1759 du roi de France Henri IV « le Grand roi »\n2 TYPE Chef d’état\n2 DATE 2 AUG 1589\n2 NOTE voir [Henri_IV_(roi_de_France)](https://fr.wikipedia.org/wiki/Henri_IV_(roi_de_France))",
"1 EVEN Sacre à Reims le 17 octobre 1710 du roi de France Louis XIII « le Juste »\n2 TYPE Chef d’état\n2 DATE 14 MAY 1610\n2 NOTE voir [Louis_XIII](https://fr.wikipedia.org/wiki/Louis_XIII)",
"1 EVEN Sacre à Reims le 7 juin 1654 du roi de France Louis XIV « le Grand »\n2 TYPE Chef d’état\n2 DATE 14 MAY 1643\n2 NOTE  Il aura le règne le plus long de l’histoire de la France.\n3 CONT voir [Louis_XIV](https://fr.wikipedia.org/wiki/Louis_XIV)",
"1 EVEN Sacre à Reims le 25 octobre 1722 du roi de France Louis XV « le Bien-Aimé » \n2 TYPE Chef d’état\n2 DATE 1 SEP 1715\n2 NOTE  Il succède à son arrière-grand-père Louis XIV à l'âge de cinq ans. La régence est exercée par le duc Philippe d'Orléans\n3 CONT voir [Louis_XV](https://fr.wikipedia.org/wiki/Louis_XV)",
"1 EVEN Sacre à Reims le 11 juin 1775 du roi de France Louis XVI \n2 TYPE Chef d’état\n2 DATE 10 MAY 1774\n2 NOTE Il est le dernier roi de France de la période dite de l'Ancien Régime. \n3 CONT voir [Louis_XVI](https://fr.wikipedia.org/wiki/Louis_XVI)",
"1 EVEN Directoire (ensemble de cinq directeurs)\n2 TYPE Chef d’état\n2 DATE 26 OCT 1795\n2 NOTE voir [Directoire](https://fr.wikipedia.org/wiki/Directoire)",
"1 EVEN Consulat : régime autoritaire dirigé, en théorie, par trois consuls\n2 TYPE Chef d’état\n2 DATE 9 NOV 1799\n2 NOTE Le coup d’État du 18 brumaire an VIII exécuté par Napoléon Bonaparte marque la fin du Directoire et de la Révolution française.\n3 CONT voir [Consulat_(histoire_de_France)](https://fr.wikipedia.org/wiki/Consulat_(histoire_de_France))",
"1 EVEN Sacre à Notre-Dame à Paris le 2 décembre 1804 de l’empereur des Français Napoléon Ier\n2 TYPE Chef d’état\n2 DATE 18 MAY 1804\n2 NOTE  \n3 CONT voir [Napoléon_Ier](https://fr.wikipedia.org/wiki/Napoléon_Ier)",
"1 EVEN Louis XVIII « le Désiré » se proclame roi de France\n2 TYPE Chef d’état\n2 DATE 22 JUN 1815\n2 NOTE Le 20 mars 1815, il abandonne le pouvoir (fuite) au retour de Napoléon 1er.\n3 CONT voir [Louis_XVIII](https://fr.wikipedia.org/wiki/Louis_XVIII)",
"1 EVEN Napoléon 1er revient à Paris\n2 TYPE Chef d’état\n2 DATE 20 MAR 1815\n2 NOTE Il abdique le 22 juin 1815, 4 jours après la défaite de Waterloo.\n3 CONT voir [Napoléon_Ier](https://fr.wikipedia.org/wiki/Napoléon_Ier)",
"1 EVEN Retour de Louis XVIII\n2 TYPE Chef d’état\n2 DATE 8 JUL 1815\n2 NOTE Dernier monarque de France mort au pouvoir, il n’a jamais été sacré.\n3 CONT voir [Louis_XVIII](https://fr.wikipedia.org/wiki/Louis_XVIII)",
"1 EVEN Sacre à Reims le 29 mai 1825 du roi de France Charles X \n2 TYPE Chef d’état\n2 DATE 16 SEP 1824\n2 NOTE Plus vieux roi à accéder au pouvoir. Il abdique en faveur de Henri V qui ne règnera pas.\n3 CONT voir [Charles_X](https://fr.wikipedia.org/wiki/Charles_X)",
"1 EVEN Louis-Philippe Ier est proclamé roi des Français\n2 TYPE Chef d’état\n2 DATE 9 AUG 1830\n2 NOTE Louis-Philippe est le dernier roi en France mais sous le titre de « roi des Français ».\n3 CONT voir [Louis-Philippe_Ier](https://fr.wikipedia.org/wiki/Louis-Philippe_Ier)",
"1 EVEN Louis-Napoléon Bonaparte élu président de la Iième République\n2 TYPE Chef d’état\n2 DATE 4 NOV 1848\n2 NOTE  Louis-Napoléon Bonaparte 1er est le premier chef d’État français élu au suffrage universel le 10 décembre 1848  et le premier à porter le titre de président de la République française.\n3 CONT voir [Napoéon_III](https://fr.wikipedia.org/wiki/Napoéon_III)",
"1 EVEN Un coup d’état permet à Napoléon III de se proclamer empereur des Français\n2 TYPE Chef d’état\n2 DATE 4 DEC 1852\n2 NOTE  Il meurt en exil en Angleterre en janvier 1873.\n3 CONT voir [Napoléon_III](https://fr.wikipedia.org/wiki/Napoléon_III)",
"1 EVEN Adolphe Thiers est élu 1er président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 31 AUG 1871\n2 NOTE voir [Présidence_d'Adolphe_Thiers](https://fr.wikipedia.org/wiki/Présidence_d'Adolphe_Thiers)",
"1 EVEN Patrice de Mac Mahon est élu 2ème président de la République\n2 TYPE Chef d’état\n2 DATE 24 MAY 1873\n2 NOTE Il visait à rétablir la monarchie.\n3 CONT voir [Présidence_de_Patrice_de_Mac_Mahon](https://fr.wikipedia.org/wiki/Présidence_de_Patrice_de_Mac_Mahon)",
"1 EVEN Jules Grévy est élu 3ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 30 JAN 1879\n2 NOTE voir [Présidence_de_Jules_Grévy](https://fr.wikipedia.org/wiki/Présidence_de_Jules_Grévy)",
"1 EVEN Sadi Carnot est élu 4ème président de la Iième République\n2 TYPE Chef d’état\n2 DATE 3 DEC 1887\n2 NOTE Il sera assassiné le 25 juin 1894 à Lyon.\n3 CONT voir [Présidence_de_Sadi_Carnot](https://fr.wikipedia.org/wiki/Présidence_de_Sadi_Carnot)",
"1 EVEN Jean Casimir-Perrier est élu 6ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 28 JUN 1894\n2 NOTE voir [Présidence_de_Jean_Casimir-Perier](https://fr.wikipedia.org/wiki/Présidence_de_Jean_Casimir-Perier)",
"1 EVEN Félix Faure est élu 7ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 17 JAN 1895\n2 NOTE voir [Présidence_de_Félix_Faure](https://fr.wikipedia.org/wiki/Présidence_de_Félix_Faure)",
"1 EVEN Émile Loubet est élu 8ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 18 FEB 1899\n2 NOTE voir [Présidence_d'çmile_Loubet](https://fr.wikipedia.org/wiki/Présidence_d'çmile_Loubet)",
"1 EVEN Armand Fallières est élu 9ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 18 FEB 1906\n2 NOTE voir [Présidence_d'Armand_Fallières](https://fr.wikipedia.org/wiki/Présidence_d'Armand_Fallières)",
"1 EVEN Raymond Poincaré est élu 10ème Président de la République\n2 TYPE Chef d’état\n2 DATE 18 FEB 1913\n2 NOTE voir [Présidence_de_Raymond_Poincaré](https://fr.wikipedia.org/wiki/Présidence_de_Raymond_Poincaré)",
"1 EVEN Paul Deschanel est élu 11ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 18 FEB 1920\n2 NOTE voir [Présidence_de_Paul_Deschanel](https://fr.wikipedia.org/wiki/Présidence_de_Paul_Deschanel)",
"1 EVEN Alexandre Millerand est élu 12ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 23 SEP 1920\n2 NOTE voir [Présidence_d'Alexandre_Millerand](https://fr.wikipedia.org/wiki/Présidence_d'Alexandre_Millerand)",
"1 EVEN Gaston Doumergue est élu 13ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 13 JUN 1924\n2 NOTE voir [Présidence_de_Gaston_Doumergue](https://fr.wikipedia.org/wiki/Présidence_de_Gaston_Doumergue)",
"1 EVEN Paul Doumer est élu 14ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 13 JUN 1931\n2 NOTE Il meurt assassiné le 7 mai 1932\n3 CONT voir [Présidence_de_Paul_Doumer](https://fr.wikipedia.org/wiki/Présidence_de_Paul_Doumer)",
"1 EVEN Albert Lebrun est élu 15ème président de la IIIème République\n2 TYPE Chef d’état\n2 DATE 10 MAY 1931\n2 NOTE voir [Présidence_d'Albert_Lebrun](https://fr.wikipedia.org/wiki/Présidence_d'Albert_Lebrun)",
"1 EVEN Le maréchal Philippe Pétain est nommé président du Conseil par Albert Lebrun.\n2 TYPE Chef d’état\n2 DATE 16 JUN 1940\n2 NOTE voir [Philippe_Pétain](https://fr.wikipedia.org/wiki/Philippe_Pétain)",
"1 EVEN Le général de Gaulle est président du Gouvernement provisoire de la République Française.\n2 TYPE Chef d’état\n2 DATE 25 AUG 1944\n2 NOTE Il démissionne en 1946.\n3 CONT voir [Charles_de_Gaulle](https://fr.wikipedia.org/wiki/Charles_de_Gaulle)",
"1 EVEN Félix Gouin est président du gouvernement provisoire de la République Française\n2 TYPE Chef d’état\n2 DATE 23 JAN 1946\n2 NOTE voir [élix_Gouin](https://fr.wikipedia.org/wiki/élix_Gouin)",
"1 EVEN Georges Bidault est président du gouvernement provisoire de la République Française\n2 TYPE Chef d’état\n2 DATE JUN 1946\n2 NOTE voir [Georges_Bidault](https://fr.wikipedia.org/wiki/Georges_Bidault)",
"1 EVEN Vincent Auriol est élu 1er président de la IV ème République\n2 TYPE Chef d’état\n2 DATE 16 JAN 1947\n2 NOTE voir [Présidence_de_Vincent_Auriol](https://fr.wikipedia.org/wiki/Présidence_de_Vincent_Auriol)",
"1 EVEN René Coty est élu 2nd président de la IV ème République\n2 TYPE Chef d’état\n2 DATE 16 JAN 1954\n2 NOTE voir [Présidence_de_René_Coty](https://fr.wikipedia.org/wiki/Présidence_de_René_Coty)",
"1 EVEN Charles de Gaulle est élu 1er président de la Vème République\n2 TYPE Chef d’état\n2 DATE 8 JAN 1959\n2 NOTE voir [Présidence_de_Charles_de_Gaulle](https://fr.wikipedia.org/wiki/Présidence_de_Charles_de_Gaulle)",
"1 EVEN Georges Pompidou est élu 2ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 20 JUN 1969\n2 NOTE voir [Présidence_de_Georges_Pompidou](https://fr.wikipedia.org/wiki/Présidence_de_Georges_Pompidou)",
"1 EVEN Valéry Giscard d’Estaing est élu 3ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 27 MAY 1974\n2 NOTE voir [Présidence_de_Valéry_Giscard_d’Estaing](https://fr.wikipedia.org/wiki/Présidence_de_Valéry_Giscard_d’Estaing)",
"1 EVEN François Mitterrand est élu 4ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 21 MAY 1981\n2 NOTE Il sera ré-élu le 21 mai 1988\n3 CONT voir [Première_présidence_de_François_Mitterrand](https://fr.wikipedia.org/wiki/Première_présidence_de_François_Mitterrand)",
"1 EVEN Jacques Chirac est élu 5ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 17 MAY 1995\n2 NOTE Il sera ré-élu le 17 mai 2002.\n3 CONT voir [Présidence_de_Jacques_Chirac](https://fr.wikipedia.org/wiki/Présidence_de_Jacques_Chirac)",
"1 EVEN Nicolas Sarkozy est élu 6ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 16 MAY 2007\n2 NOTE voir [Présidence_de_Nicolas_Sarkozy](https://fr.wikipedia.org/wiki/Présidence_de_Nicolas_Sarkozy)",
"1 EVEN François Hollande est élu 7ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 15 MAY 2012\n2 NOTE voir [Présidence_de_François_Hollande](https://fr.wikipedia.org/wiki/Présidence_de_François_Hollande)",
"1 EVEN Emmanuel Macron est élu 8ème président de la Vème République\n2 TYPE Chef d’état\n2 DATE 14 MAY 2017\n2 NOTE Il sera ré-élu le 14 mai 2022\n3 CONT voir [Première_présidence_d'Emmanuel_Macron](https://fr.wikipedia.org/wiki/Première_présidence_d'Emmanuel_Macron)",

				]);

			default:
				return new Collection();
		}
	}
};
/** Bonne utilisation */